[![Documentation Status](https://readthedocs.org/projects/rxpipes/badge/?version=latest)](https://rxpipes.readthedocs.io/en/latest/?badge=latest)
[![CircleCI](https://circleci.com/gh/shirecoding/RxPipes.svg?style=shield)](https://app.circleci.com/pipelines/github/shirecoding/RxPipes)
[![CodeFactor](https://www.codefactor.io/repository/github/shirecoding/rxpipes/badge)](https://www.codefactor.io/repository/github/shirecoding/rxpipes)

# RxPipes
A thin wrapper around RxPy for data-flow programming.

## Documentation

- [readthedocs](https://rxpipes.readthedocs.io/en/latest/)
